_version_ = '0.1.0'
import random
def whp(what_do_you_want_to_print):
  while True:
    print(what_do_you_want_to_print)
def fop(how_many_times, what_do_you_want_to_print):
  for i in range(how_many_times):
    print(what_do_you_want_to_print)
def foc(range_):
  for i in range(range_):
    print(i)
def fori(what_do_you_want_to_print_random_in_range_0_100):
  a = random.randint(0, 100)
  for i in range(a):
    print(what_do_you_want_to_print_random_in_range_0_100)
def wht():
    while True:
        True
def cal(put_math_problem):
    while True:
        z = eval(put_math_problem)
        print(z)
